==> jmb.tools-0.2.6.tar.gz: jmb.tools-0.2.6/jmb/tools/stat/push.py <==
# coding: utf-8

import re
from time import sleep
from six.moves import configparser
from .client import StatsClient
from ..conf import read, configure
from pprint import pprint
import click

@click.command('push')
@click.option('--host/--no-host', is_flag=True, default=None, help="Push just info on host and keys")
@click.option('--project/--no-project', is_flag=None, default=None,
              help="Push just info on projects and apps")
@click.option('-d', '--directory', help="the directory of the project to be pushed", default=".")
@click.option('-d', '--dev', 'settings', flag_value='dev', default=True, help="This is a dev system")
@click.option('-s', '--staging', 'settings', flag_value='staging', default=True, help="This is a staging system")
@click.option('-p', '--production', 'settings', flag_value='production', help="This is a production system")
@click.option('-t', '--test', is_flag=True, help="The project is not yet in production")
@click.option('-P', '--pattern', help="A pattern to filter which packages to push")
@click.pass_context
def push_info(ctx, host, project, directory, settings, test, pattern):
    """Push info on remote server"""

    try:
        user, password = ctx.obj.get('stats', 'user'), ctx.obj.get('stats', 'password')
    except configparser.NoSectionError:
        configure.create_customization(ctx.obj)
        return
    sc = StatsClient(ctx.obj.get('stats', 'api_url'), user, password)
    host, project = parse_flags(host, project)

    if host:
        data = read.get_server_info()
        sc.servers.add_or_update(data)

    if project:
        data = read.get_project_info(directory, test)
        if ctx.parent.parent.verbose:
            click.secho("Update host {}".format(data['name']), fg='magenta')
        sc.projects.add_or_update(data)

        apps = read.get_packages()
        project_name = data['name']

        for app, app_data in apps.items():
            if pattern:
                if not re.search(pattern, app):
                    continue
            if ctx.parent.parent.verbose:
                try:
                    num = app_data['rev'] if 'rev' in app_data else app_data['version']
                    click.secho("{} - {}".format(app, num), fg='magenta')
                except:
                    import ipdb; ipdb.set_trace()

            app_data.update({
                'project': project_name,
                'app': app,
            })

            sc.appproject.add_or_update_by_slugs(project_name, app, app_data)
            #sleep(.5)

@click.command('show')
@click.option('--host/--no-host', is_flag=True, default=None, help="Push just info on host and keys")
@click.option('--project/--no-project', is_flag=None, default=None,
              help="Push just info on projects and apps")
@click.option('-d', '--directory', help="the directory of the project to be pushed", default=".")
@click.option('-d', '--dev', 'settings', flag_value='dev', default=True, help="This is a dev system")
@click.option('-s', '--staging', 'settings', flag_value='staging', default=True, help="This is a staging system")
@click.option('-p', '--production', 'settings', flag_value='production', help="This is a production sysm")
@click.option('-t', '--test', is_flag=True, help="The project is not yet in production")
def show(host, project, directory, settings, test):
    """Show all info that will be pushed"""
    data = {}

    host, project = parse_flags(host, project)

    if host:
        data['server'] = read.get_server_info()

    if project:
        data['project'] = read.get_project_info(directory, test)

    pprint(data)


@click.command('test')
@click.pass_context
def test(ctx):
    """test if the client can connect to the server"""

    user, password = ctx.obj.get('stats', 'user'), ctx.obj.get('stats', 'password')
    sc = StatsClient(ctx.obj.get('stats', 'api_url'), user, password)
    try:
        sc.test()
        click.secho("Ok!", fg="green")
    except Exception as e:
        error = sc.resp.json()['detail']
        click.secho("Not connected! {}".format(error), fg="red")

def parse_flags(a, b):
    if a is None and b is None:
        return True, True
    if a is None and b is True:
        return False, True
    if a is None and b is False:
        return True, False
    if a is True and b is None:
        return True, False
    if a is False and b in None:
        return False, True

==> jmb.tools-0.2.7.tar.gz: jmb.tools-0.2.7/jmb/tools/stat/push.py <==
# coding: utf-8

import re
import os
from time import sleep
from pprint import pprint

from six.moves import configparser
from .client import StatsClient
from ..conf import read, configure
import click

@click.command('push')
@click.option('--host/--no-host', is_flag=True, default=None, help="Push just info on host and keys")
@click.option('--project/--no-project', is_flag=None, default=None,
              help="Push just info on projects and apps")
@click.option('-d', '--dev', 'settings', flag_value='dev', default=True, help="This is a dev system")
@click.option('-s', '--staging', 'settings', flag_value='staging', default=True, help="This is a staging system")
@click.option('-p', '--production', 'settings', flag_value='production', help="This is a production system")
@click.option('-t', '--test', is_flag=True, help="The project is not yet in production")
@click.option('-P', '--pattern', help="A pattern to filter which packages to push")
@click.argument('repositories', nargs=-1)
@click.pass_context
def push_info(ctx, host, project, settings, test, pattern, repositories):
    """Push info on remote server for each repo in argument (a directory)"""

    try:
        user, password = ctx.obj.get('stats', 'user'), ctx.obj.get('stats', 'password')
    except configparser.NoSectionError:
        configure.create_customization(ctx.obj)
        return
    sc = StatsClient(ctx.obj.get('stats', 'api_url'), user, password)
    host, project = parse_flags(host, project)

    if host:
        data = read.get_server_info()
        sc.servers.add_or_update(data)

    if project:
        cwd = os.getcwd()
        for repo in repositories or ".":
            os.chdir(repo)
            push_project_info(ctx, pattern, sc, test)
            os.chdir(cwd)

def push_project_info(ctx, pattern, sc, test, directory="."):
    """Push all info on the project in directory"""

    try:
        data = read.get_project_info('.', test)
    except read.CollectInfoException as e:
        click.secho("get_project_info raised CollectInfoError: ", nl=False)
        click.secho("{}".format(e.message), fg='red', reverse=True)
        return

    if ctx.parent.parent.verbose:
        click.secho("Update host {}".format(data['name']), fg='magenta')
    sc.projects.add_or_update(data)


    apps = read.get_packages()
    project_name = data['name']

    for app, app_data in apps.items():

        if pattern:
            if not re.search(pattern, app):
                continue
        if ctx.parent.parent.verbose:
            num = app_data['rev'] if 'rev' in app_data else app_data['version']
            click.secho("{} - {}".format(app, num), fg='magenta')

        app_data.update({
            'project': project_name,
            'app': app,
        })

        sc.appproject.add_or_update_by_slugs(project_name, app, app_data)
        #sleep(.5)


@click.command('show')
@click.option('--host/--no-host', is_flag=True, default=None, help="Push just info on host and keys")
@click.option('--project/--no-project', is_flag=None, default=None,
              help="Push just info on projects and apps")
@click.option('-d', '--directory', help="the directory of the project to be pushed", default=".")
@click.option('-d', '--dev', 'settings', flag_value='dev', default=True, help="This is a dev system")
@click.option('-s', '--staging', 'settings', flag_value='staging', default=True, help="This is a staging system")
@click.option('-p', '--production', 'settings', flag_value='production', help="This is a production sysm")
@click.option('-t', '--test', is_flag=True, help="The project is not yet in production")
def show(host, project, directory, settings, test):
    """Show all info that will be pushed"""
    data = {}

    host, project = parse_flags(host, project)

    os.chdir(directory)
    if host:
        data['server'] = read.get_server_info()

    if project:
        data['project'] = read.get_project_info('.', test)

    pprint(data)


@click.command('test')
@click.pass_context
def test(ctx):
    """test if the client can connect to the server"""

    user, password = ctx.obj.get('stats', 'user'), ctx.obj.get('stats', 'password')
    sc = StatsClient(ctx.obj.get('stats', 'api_url'), user, password)
    try:
        sc.test()
        click.secho("Ok!", fg="green")
    except Exception as e:
        error = sc.resp.json()['detail']
        click.secho("Not connected! {}".format(error), fg="red")

def parse_flags(a, b):
    if a is None and b is None:
        return True, True
    if a is None and b is True:
        return False, True
    if a is None and b is False:
        return True, False
    if a is True and b is None:
        return True, False
    if a is False and b in None:
        return False, True
